/*********************                                                        */
/*! \file module_template.h
 ** \verbatim
 ** Top contributors (to current version):
 **   Mathias Preiner
 ** This file is part of the CVC4 project.
 ** Copyright (c) 2009-2019 by the authors listed in the file AUTHORS
 ** in the top-level source directory) and their institutional affiliations.
 ** All rights reserved.  See the file COPYING in the top-level source
 ** directory for licensing information.\endverbatim
 **
 ** \brief Contains code for handling command-line options.
 **
 ** For each <module>_options.toml configuration file, mkoptions.py
 ** expands this template and generates a <module>_options.h file.
 **/

#include "cvc4_private.h"

#ifndef __CVC4__OPTIONS__BASE_H
#define __CVC4__OPTIONS__BASE_H

#include "options/options.h"

#include "options/language.h"
#include <iosfwd>


#define CVC4_OPTIONS__BASE__FOR_OPTION_HOLDER \
  binary_name__option_t::type binary_name;\
  bool binary_name__setByUser__; \
  err__option_t::type err;\
  bool err__setByUser__; \
  in__option_t::type in;\
  bool in__setByUser__; \
  inputLanguage__option_t::type inputLanguage;\
  bool inputLanguage__setByUser__; \
  languageHelp__option_t::type languageHelp;\
  bool languageHelp__setByUser__; \
  out__option_t::type out;\
  bool out__setByUser__; \
  outputLanguage__option_t::type outputLanguage;\
  bool outputLanguage__setByUser__; \
  parseOnly__option_t::type parseOnly;\
  bool parseOnly__setByUser__; \
  preprocessOnly__option_t::type preprocessOnly;\
  bool preprocessOnly__setByUser__; \
  printSuccess__option_t::type printSuccess;\
  bool printSuccess__setByUser__; \
  statistics__option_t::type statistics;\
  bool statistics__setByUser__; \
  statsEveryQuery__option_t::type statsEveryQuery;\
  bool statsEveryQuery__setByUser__; \
  statsHideZeros__option_t::type statsHideZeros;\
  bool statsHideZeros__setByUser__; \
  verbosity__option_t::type verbosity;\
  bool verbosity__setByUser__;


namespace CVC4 {

namespace options {

extern struct CVC4_PUBLIC binary_name__option_t
{
  typedef std::string type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} binary_name CVC4_PUBLIC;
extern struct CVC4_PUBLIC err__option_t
{
  typedef std::ostream* type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} err CVC4_PUBLIC;
extern struct CVC4_PUBLIC in__option_t
{
  typedef std::istream* type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} in CVC4_PUBLIC;
extern struct CVC4_PUBLIC inputLanguage__option_t
{
  typedef InputLanguage type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} inputLanguage CVC4_PUBLIC;
extern struct CVC4_PUBLIC languageHelp__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} languageHelp CVC4_PUBLIC;
extern struct CVC4_PUBLIC out__option_t
{
  typedef std::ostream* type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} out CVC4_PUBLIC;
extern struct CVC4_PUBLIC outputLanguage__option_t
{
  typedef OutputLanguage type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} outputLanguage CVC4_PUBLIC;
extern struct CVC4_PUBLIC parseOnly__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} parseOnly CVC4_PUBLIC;
extern struct CVC4_PUBLIC preprocessOnly__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
} preprocessOnly CVC4_PUBLIC;
extern struct CVC4_PUBLIC printSuccess__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
} printSuccess CVC4_PUBLIC;
extern struct CVC4_PUBLIC statistics__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
} statistics CVC4_PUBLIC;
extern struct CVC4_PUBLIC statsEveryQuery__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
} statsEveryQuery CVC4_PUBLIC;
extern struct CVC4_PUBLIC statsHideZeros__option_t
{
  typedef bool type;
  type operator()() const;
  bool wasSetByUser() const;
} statsHideZeros CVC4_PUBLIC;
extern struct CVC4_PUBLIC verbosity__option_t
{
  typedef int type;
  type operator()() const;
  bool wasSetByUser() const;
  void set(const type& v);
} verbosity CVC4_PUBLIC;


}  // namespace options

template <> void Options::set(
    options::binary_name__option_t,
    const options::binary_name__option_t::type& x);
template <> const options::binary_name__option_t::type& Options::operator[](
    options::binary_name__option_t) const;
template <> bool Options::wasSetByUser(options::binary_name__option_t) const;
template <> void Options::assign(
    options::binary_name__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::err__option_t,
    const options::err__option_t::type& x);
template <> const options::err__option_t::type& Options::operator[](
    options::err__option_t) const;
template <> bool Options::wasSetByUser(options::err__option_t) const;
template <> void Options::assign(
    options::err__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::in__option_t,
    const options::in__option_t::type& x);
template <> const options::in__option_t::type& Options::operator[](
    options::in__option_t) const;
template <> bool Options::wasSetByUser(options::in__option_t) const;
template <> void Options::assign(
    options::in__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::inputLanguage__option_t,
    const options::inputLanguage__option_t::type& x);
template <> const options::inputLanguage__option_t::type& Options::operator[](
    options::inputLanguage__option_t) const;
template <> bool Options::wasSetByUser(options::inputLanguage__option_t) const;
template <> void Options::assign(
    options::inputLanguage__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::languageHelp__option_t,
    const options::languageHelp__option_t::type& x);
template <> const options::languageHelp__option_t::type& Options::operator[](
    options::languageHelp__option_t) const;
template <> bool Options::wasSetByUser(options::languageHelp__option_t) const;
template <> void Options::assignBool(
    options::languageHelp__option_t,
    std::string option,
    bool value);
template <> void Options::set(
    options::out__option_t,
    const options::out__option_t::type& x);
template <> const options::out__option_t::type& Options::operator[](
    options::out__option_t) const;
template <> bool Options::wasSetByUser(options::out__option_t) const;
template <> void Options::assign(
    options::out__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::outputLanguage__option_t,
    const options::outputLanguage__option_t::type& x);
template <> const options::outputLanguage__option_t::type& Options::operator[](
    options::outputLanguage__option_t) const;
template <> bool Options::wasSetByUser(options::outputLanguage__option_t) const;
template <> void Options::assign(
    options::outputLanguage__option_t,
    std::string option,
    std::string value);
template <> void Options::set(
    options::parseOnly__option_t,
    const options::parseOnly__option_t::type& x);
template <> const options::parseOnly__option_t::type& Options::operator[](
    options::parseOnly__option_t) const;
template <> bool Options::wasSetByUser(options::parseOnly__option_t) const;
template <> void Options::assignBool(
    options::parseOnly__option_t,
    std::string option,
    bool value);
template <> const options::preprocessOnly__option_t::type& Options::operator[](
    options::preprocessOnly__option_t) const;
template <> bool Options::wasSetByUser(options::preprocessOnly__option_t) const;
template <> void Options::assignBool(
    options::preprocessOnly__option_t,
    std::string option,
    bool value);
template <> const options::printSuccess__option_t::type& Options::operator[](
    options::printSuccess__option_t) const;
template <> bool Options::wasSetByUser(options::printSuccess__option_t) const;
template <> void Options::assignBool(
    options::printSuccess__option_t,
    std::string option,
    bool value);
template <> const options::statistics__option_t::type& Options::operator[](
    options::statistics__option_t) const;
template <> bool Options::wasSetByUser(options::statistics__option_t) const;
template <> void Options::assignBool(
    options::statistics__option_t,
    std::string option,
    bool value);
template <> const options::statsEveryQuery__option_t::type& Options::operator[](
    options::statsEveryQuery__option_t) const;
template <> bool Options::wasSetByUser(options::statsEveryQuery__option_t) const;
template <> void Options::assignBool(
    options::statsEveryQuery__option_t,
    std::string option,
    bool value);
template <> const options::statsHideZeros__option_t::type& Options::operator[](
    options::statsHideZeros__option_t) const;
template <> bool Options::wasSetByUser(options::statsHideZeros__option_t) const;
template <> void Options::assignBool(
    options::statsHideZeros__option_t,
    std::string option,
    bool value);
template <> void Options::set(
    options::verbosity__option_t,
    const options::verbosity__option_t::type& x);
template <> const options::verbosity__option_t::type& Options::operator[](
    options::verbosity__option_t) const;
template <> bool Options::wasSetByUser(options::verbosity__option_t) const;
template <> void Options::assign(
    options::verbosity__option_t,
    std::string option,
    std::string value);


namespace options {

inline binary_name__option_t::type binary_name__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool binary_name__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void binary_name__option_t::set(const binary_name__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline err__option_t::type err__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool err__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void err__option_t::set(const err__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline in__option_t::type in__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool in__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void in__option_t::set(const in__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline inputLanguage__option_t::type inputLanguage__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool inputLanguage__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void inputLanguage__option_t::set(const inputLanguage__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline languageHelp__option_t::type languageHelp__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool languageHelp__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void languageHelp__option_t::set(const languageHelp__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline out__option_t::type out__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool out__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void out__option_t::set(const out__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline outputLanguage__option_t::type outputLanguage__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool outputLanguage__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void outputLanguage__option_t::set(const outputLanguage__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline parseOnly__option_t::type parseOnly__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool parseOnly__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void parseOnly__option_t::set(const parseOnly__option_t::type& v)
{
  Options::current()->set(*this, v);
}
inline preprocessOnly__option_t::type preprocessOnly__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool preprocessOnly__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline printSuccess__option_t::type printSuccess__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool printSuccess__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline statistics__option_t::type statistics__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool statistics__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline statsEveryQuery__option_t::type statsEveryQuery__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool statsEveryQuery__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline statsHideZeros__option_t::type statsHideZeros__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool statsHideZeros__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline verbosity__option_t::type verbosity__option_t::operator()() const
{
  return (*Options::current())[*this];
}
inline bool verbosity__option_t::wasSetByUser() const
{
  return Options::current()->wasSetByUser(*this);
}
inline void verbosity__option_t::set(const verbosity__option_t::type& v)
{
  Options::current()->set(*this, v);
}


}  // namespace options
}  // namespace CVC4

#endif /* __CVC4__OPTIONS__BASE_H */
